@@ -1,4 +1,4 @@
-from ploomber.cli.parsers import _custom_command, CustomParser
+from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 
 
@@ -11,6 +11,6 @@ def main():
             '-o',
             help='Where to save the report, defaults to pipeline.html',
             default='pipeline.html')
-    dag, args = _custom_command(parser)
+    dag, args = parser.load_from_entry_point_arg()
     dag.to_markup(path=args.output)
     print('Report saved at:', args.output)
